@@ -17,6 +17,7 @@ import json
 import argparse
 
 from . import protobuf_parse as parser
+# import protobuf_parse as parser
 
 __version__ = '1.0'
 
@@ -102,6 +103,7 @@ class ProtoBufParser(object):
         }
 
         for file_name in glob.glob(os.path.join(self.input_dir, '*.proto')):
+            print(file_name)
 
             module = os.path.splitext(os.path.basename(file_name))[0]
             module_dict = {'name': module, 'imports': []}
@@ -171,7 +173,7 @@ def main():
     arg_parse = argparse.ArgumentParser(description=USAGE, epilog=EPILOG, formatter_class=argparse.RawTextHelpFormatter)
 
     # add parser options
-    arg_parse.add_argument('target', choices=['dmi'], default='dmi',
+    arg_parse.add_argument('target', choices=['dmi', 'voltha'],
                            help="Target type of which the ProtocolBuffer files shall be converted to the JSON file.")
     arg_parse.add_argument('target_version', help="Version number of the ProtocolBuffer files.")
 
